# coding: utf-8

"""
    LIFF server API

    LIFF Server API.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class LiffScope(str, Enum):
    """
    Array of scopes required for some LIFF SDK methods to function. The default value is `[\"profile\", \"chat_message.write\"]`.  
    """

    """
    allowed enum values
    """
    OPENID = 'openid'
    EMAIL = 'email'
    PROFILE = 'profile'
    CHAT_MESSAGE_DOT_WRITE = 'chat_message.write'

    @classmethod
    def from_json(cls, json_str: str) -> LiffScope:
        """Create an instance of LiffScope from a JSON string"""
        return LiffScope(json.loads(json_str))


