# coding: utf-8

"""
    LINE Messaging API(Insight)

    This document describes LINE Messaging API(Insight).  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic.v1 import BaseModel, Field, StrictFloat, StrictInt, StrictStr, validator

class AgeTile(BaseModel):
    """
    AgeTile
    """
    age: Optional[StrictStr] = Field(None, description="users' age")
    percentage: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="Percentage")

    __properties = ["age", "percentage"]

    @validator('age')
    def age_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('from0to14', 'from15to19', 'from20to24', 'from25to29', 'from30to34', 'from35to39', 'from40to44', 'from45to49', 'from50', 'from50to54', 'from55to59', 'from60to64', 'from65to69', 'from70', 'unknown'):
            raise ValueError("must be one of enum values ('from0to14', 'from15to19', 'from20to24', 'from25to29', 'from30to34', 'from35to39', 'from40to44', 'from45to49', 'from50', 'from50to54', 'from55to59', 'from60to64', 'from65to69', 'from70', 'unknown')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AgeTile:
        """Create an instance of AgeTile from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AgeTile:
        """Create an instance of AgeTile from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AgeTile.parse_obj(obj)

        _obj = AgeTile.parse_obj({
            "age": obj.get("age"),
            "percentage": obj.get("percentage")
        })
        return _obj

