# coding: utf-8

# flake8: noqa
"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


# import models into model package
from linebot.v3.messaging.models.acquisition_condition_request import AcquisitionConditionRequest
from linebot.v3.messaging.models.acquisition_condition_response import AcquisitionConditionResponse
from linebot.v3.messaging.models.action import Action
from linebot.v3.messaging.models.age_demographic import AgeDemographic
from linebot.v3.messaging.models.age_demographic_filter import AgeDemographicFilter
from linebot.v3.messaging.models.all_mention_target import AllMentionTarget
from linebot.v3.messaging.models.alt_uri import AltUri
from linebot.v3.messaging.models.app_type_demographic import AppTypeDemographic
from linebot.v3.messaging.models.app_type_demographic_filter import AppTypeDemographicFilter
from linebot.v3.messaging.models.area_demographic import AreaDemographic
from linebot.v3.messaging.models.area_demographic_filter import AreaDemographicFilter
from linebot.v3.messaging.models.audience_recipient import AudienceRecipient
from linebot.v3.messaging.models.audio_message import AudioMessage
from linebot.v3.messaging.models.bot_info_response import BotInfoResponse
from linebot.v3.messaging.models.broadcast_request import BroadcastRequest
from linebot.v3.messaging.models.buttons_template import ButtonsTemplate
from linebot.v3.messaging.models.camera_action import CameraAction
from linebot.v3.messaging.models.camera_roll_action import CameraRollAction
from linebot.v3.messaging.models.carousel_column import CarouselColumn
from linebot.v3.messaging.models.carousel_template import CarouselTemplate
from linebot.v3.messaging.models.cash_back_fixed_price_info_request import CashBackFixedPriceInfoRequest
from linebot.v3.messaging.models.cash_back_fixed_price_info_response import CashBackFixedPriceInfoResponse
from linebot.v3.messaging.models.cash_back_percentage_price_info_request import CashBackPercentagePriceInfoRequest
from linebot.v3.messaging.models.cash_back_percentage_price_info_response import CashBackPercentagePriceInfoResponse
from linebot.v3.messaging.models.cash_back_price_info_request import CashBackPriceInfoRequest
from linebot.v3.messaging.models.cash_back_price_info_response import CashBackPriceInfoResponse
from linebot.v3.messaging.models.chat_reference import ChatReference
from linebot.v3.messaging.models.clipboard_action import ClipboardAction
from linebot.v3.messaging.models.clipboard_imagemap_action import ClipboardImagemapAction
from linebot.v3.messaging.models.confirm_template import ConfirmTemplate
from linebot.v3.messaging.models.coupon_cash_back_reward_request import CouponCashBackRewardRequest
from linebot.v3.messaging.models.coupon_cash_back_reward_response import CouponCashBackRewardResponse
from linebot.v3.messaging.models.coupon_create_request import CouponCreateRequest
from linebot.v3.messaging.models.coupon_create_response import CouponCreateResponse
from linebot.v3.messaging.models.coupon_discount_reward_request import CouponDiscountRewardRequest
from linebot.v3.messaging.models.coupon_discount_reward_response import CouponDiscountRewardResponse
from linebot.v3.messaging.models.coupon_free_reward_request import CouponFreeRewardRequest
from linebot.v3.messaging.models.coupon_free_reward_response import CouponFreeRewardResponse
from linebot.v3.messaging.models.coupon_gift_reward_request import CouponGiftRewardRequest
from linebot.v3.messaging.models.coupon_gift_reward_response import CouponGiftRewardResponse
from linebot.v3.messaging.models.coupon_list_response import CouponListResponse
from linebot.v3.messaging.models.coupon_message import CouponMessage
from linebot.v3.messaging.models.coupon_others_reward_request import CouponOthersRewardRequest
from linebot.v3.messaging.models.coupon_others_reward_response import CouponOthersRewardResponse
from linebot.v3.messaging.models.coupon_response import CouponResponse
from linebot.v3.messaging.models.coupon_reward_request import CouponRewardRequest
from linebot.v3.messaging.models.coupon_reward_response import CouponRewardResponse
from linebot.v3.messaging.models.create_rich_menu_alias_request import CreateRichMenuAliasRequest
from linebot.v3.messaging.models.datetime_picker_action import DatetimePickerAction
from linebot.v3.messaging.models.demographic_filter import DemographicFilter
from linebot.v3.messaging.models.discount_explicit_price_info_request import DiscountExplicitPriceInfoRequest
from linebot.v3.messaging.models.discount_explicit_price_info_response import DiscountExplicitPriceInfoResponse
from linebot.v3.messaging.models.discount_fixed_price_info_request import DiscountFixedPriceInfoRequest
from linebot.v3.messaging.models.discount_fixed_price_info_response import DiscountFixedPriceInfoResponse
from linebot.v3.messaging.models.discount_percentage_price_info_request import DiscountPercentagePriceInfoRequest
from linebot.v3.messaging.models.discount_percentage_price_info_response import DiscountPercentagePriceInfoResponse
from linebot.v3.messaging.models.discount_price_info_request import DiscountPriceInfoRequest
from linebot.v3.messaging.models.discount_price_info_response import DiscountPriceInfoResponse
from linebot.v3.messaging.models.emoji import Emoji
from linebot.v3.messaging.models.emoji_substitution_object import EmojiSubstitutionObject
from linebot.v3.messaging.models.error_detail import ErrorDetail
from linebot.v3.messaging.models.error_response import ErrorResponse
from linebot.v3.messaging.models.filter import Filter
from linebot.v3.messaging.models.flex_block_style import FlexBlockStyle
from linebot.v3.messaging.models.flex_box import FlexBox
from linebot.v3.messaging.models.flex_box_background import FlexBoxBackground
from linebot.v3.messaging.models.flex_box_border_width import FlexBoxBorderWidth
from linebot.v3.messaging.models.flex_box_corner_radius import FlexBoxCornerRadius
from linebot.v3.messaging.models.flex_box_linear_gradient import FlexBoxLinearGradient
from linebot.v3.messaging.models.flex_box_padding import FlexBoxPadding
from linebot.v3.messaging.models.flex_box_spacing import FlexBoxSpacing
from linebot.v3.messaging.models.flex_bubble import FlexBubble
from linebot.v3.messaging.models.flex_bubble_styles import FlexBubbleStyles
from linebot.v3.messaging.models.flex_button import FlexButton
from linebot.v3.messaging.models.flex_carousel import FlexCarousel
from linebot.v3.messaging.models.flex_component import FlexComponent
from linebot.v3.messaging.models.flex_container import FlexContainer
from linebot.v3.messaging.models.flex_filler import FlexFiller
from linebot.v3.messaging.models.flex_icon import FlexIcon
from linebot.v3.messaging.models.flex_icon_size import FlexIconSize
from linebot.v3.messaging.models.flex_image import FlexImage
from linebot.v3.messaging.models.flex_image_size import FlexImageSize
from linebot.v3.messaging.models.flex_margin import FlexMargin
from linebot.v3.messaging.models.flex_message import FlexMessage
from linebot.v3.messaging.models.flex_offset import FlexOffset
from linebot.v3.messaging.models.flex_separator import FlexSeparator
from linebot.v3.messaging.models.flex_span import FlexSpan
from linebot.v3.messaging.models.flex_span_size import FlexSpanSize
from linebot.v3.messaging.models.flex_text import FlexText
from linebot.v3.messaging.models.flex_text_font_size import FlexTextFontSize
from linebot.v3.messaging.models.flex_video import FlexVideo
from linebot.v3.messaging.models.gender_demographic import GenderDemographic
from linebot.v3.messaging.models.gender_demographic_filter import GenderDemographicFilter
from linebot.v3.messaging.models.get_aggregation_unit_name_list_response import GetAggregationUnitNameListResponse
from linebot.v3.messaging.models.get_aggregation_unit_usage_response import GetAggregationUnitUsageResponse
from linebot.v3.messaging.models.get_followers_response import GetFollowersResponse
from linebot.v3.messaging.models.get_joined_membership_users_response import GetJoinedMembershipUsersResponse
from linebot.v3.messaging.models.get_membership_subscription_response import GetMembershipSubscriptionResponse
from linebot.v3.messaging.models.get_message_content_transcoding_response import GetMessageContentTranscodingResponse
from linebot.v3.messaging.models.get_webhook_endpoint_response import GetWebhookEndpointResponse
from linebot.v3.messaging.models.group_member_count_response import GroupMemberCountResponse
from linebot.v3.messaging.models.group_summary_response import GroupSummaryResponse
from linebot.v3.messaging.models.group_user_profile_response import GroupUserProfileResponse
from linebot.v3.messaging.models.image_carousel_column import ImageCarouselColumn
from linebot.v3.messaging.models.image_carousel_template import ImageCarouselTemplate
from linebot.v3.messaging.models.image_message import ImageMessage
from linebot.v3.messaging.models.imagemap_action import ImagemapAction
from linebot.v3.messaging.models.imagemap_area import ImagemapArea
from linebot.v3.messaging.models.imagemap_base_size import ImagemapBaseSize
from linebot.v3.messaging.models.imagemap_external_link import ImagemapExternalLink
from linebot.v3.messaging.models.imagemap_message import ImagemapMessage
from linebot.v3.messaging.models.imagemap_video import ImagemapVideo
from linebot.v3.messaging.models.issue_link_token_response import IssueLinkTokenResponse
from linebot.v3.messaging.models.limit import Limit
from linebot.v3.messaging.models.location_action import LocationAction
from linebot.v3.messaging.models.location_message import LocationMessage
from linebot.v3.messaging.models.lottery_acquisition_condition_request import LotteryAcquisitionConditionRequest
from linebot.v3.messaging.models.lottery_acquisition_condition_response import LotteryAcquisitionConditionResponse
from linebot.v3.messaging.models.mark_messages_as_read_request import MarkMessagesAsReadRequest
from linebot.v3.messaging.models.members_ids_response import MembersIdsResponse
from linebot.v3.messaging.models.membership import Membership
from linebot.v3.messaging.models.membership_list_response import MembershipListResponse
from linebot.v3.messaging.models.mention_substitution_object import MentionSubstitutionObject
from linebot.v3.messaging.models.mention_target import MentionTarget
from linebot.v3.messaging.models.message import Message
from linebot.v3.messaging.models.message_action import MessageAction
from linebot.v3.messaging.models.message_imagemap_action import MessageImagemapAction
from linebot.v3.messaging.models.message_quota_response import MessageQuotaResponse
from linebot.v3.messaging.models.messaging_api_pager_coupon_list_response import MessagingApiPagerCouponListResponse
from linebot.v3.messaging.models.multicast_request import MulticastRequest
from linebot.v3.messaging.models.narrowcast_progress_response import NarrowcastProgressResponse
from linebot.v3.messaging.models.narrowcast_request import NarrowcastRequest
from linebot.v3.messaging.models.normal_acquisition_condition_request import NormalAcquisitionConditionRequest
from linebot.v3.messaging.models.normal_acquisition_condition_response import NormalAcquisitionConditionResponse
from linebot.v3.messaging.models.number_of_messages_response import NumberOfMessagesResponse
from linebot.v3.messaging.models.operator_demographic_filter import OperatorDemographicFilter
from linebot.v3.messaging.models.operator_recipient import OperatorRecipient
from linebot.v3.messaging.models.pnp_messages_request import PnpMessagesRequest
from linebot.v3.messaging.models.postback_action import PostbackAction
from linebot.v3.messaging.models.push_message_request import PushMessageRequest
from linebot.v3.messaging.models.push_message_response import PushMessageResponse
from linebot.v3.messaging.models.quick_reply import QuickReply
from linebot.v3.messaging.models.quick_reply_item import QuickReplyItem
from linebot.v3.messaging.models.quota_consumption_response import QuotaConsumptionResponse
from linebot.v3.messaging.models.quota_type import QuotaType
from linebot.v3.messaging.models.recipient import Recipient
from linebot.v3.messaging.models.redelivery_recipient import RedeliveryRecipient
from linebot.v3.messaging.models.referral_acquisition_condition_response import ReferralAcquisitionConditionResponse
from linebot.v3.messaging.models.reply_message_request import ReplyMessageRequest
from linebot.v3.messaging.models.reply_message_response import ReplyMessageResponse
from linebot.v3.messaging.models.rich_menu_alias_list_response import RichMenuAliasListResponse
from linebot.v3.messaging.models.rich_menu_alias_response import RichMenuAliasResponse
from linebot.v3.messaging.models.rich_menu_area import RichMenuArea
from linebot.v3.messaging.models.rich_menu_batch_link_operation import RichMenuBatchLinkOperation
from linebot.v3.messaging.models.rich_menu_batch_operation import RichMenuBatchOperation
from linebot.v3.messaging.models.rich_menu_batch_progress_phase import RichMenuBatchProgressPhase
from linebot.v3.messaging.models.rich_menu_batch_progress_response import RichMenuBatchProgressResponse
from linebot.v3.messaging.models.rich_menu_batch_request import RichMenuBatchRequest
from linebot.v3.messaging.models.rich_menu_batch_unlink_all_operation import RichMenuBatchUnlinkAllOperation
from linebot.v3.messaging.models.rich_menu_batch_unlink_operation import RichMenuBatchUnlinkOperation
from linebot.v3.messaging.models.rich_menu_bounds import RichMenuBounds
from linebot.v3.messaging.models.rich_menu_bulk_link_request import RichMenuBulkLinkRequest
from linebot.v3.messaging.models.rich_menu_bulk_unlink_request import RichMenuBulkUnlinkRequest
from linebot.v3.messaging.models.rich_menu_id_response import RichMenuIdResponse
from linebot.v3.messaging.models.rich_menu_list_response import RichMenuListResponse
from linebot.v3.messaging.models.rich_menu_request import RichMenuRequest
from linebot.v3.messaging.models.rich_menu_response import RichMenuResponse
from linebot.v3.messaging.models.rich_menu_size import RichMenuSize
from linebot.v3.messaging.models.rich_menu_switch_action import RichMenuSwitchAction
from linebot.v3.messaging.models.room_member_count_response import RoomMemberCountResponse
from linebot.v3.messaging.models.room_user_profile_response import RoomUserProfileResponse
from linebot.v3.messaging.models.sender import Sender
from linebot.v3.messaging.models.sent_message import SentMessage
from linebot.v3.messaging.models.set_webhook_endpoint_request import SetWebhookEndpointRequest
from linebot.v3.messaging.models.show_loading_animation_request import ShowLoadingAnimationRequest
from linebot.v3.messaging.models.sticker_message import StickerMessage
from linebot.v3.messaging.models.subscribed_membership_plan import SubscribedMembershipPlan
from linebot.v3.messaging.models.subscribed_membership_user import SubscribedMembershipUser
from linebot.v3.messaging.models.subscription import Subscription
from linebot.v3.messaging.models.subscription_period_demographic import SubscriptionPeriodDemographic
from linebot.v3.messaging.models.subscription_period_demographic_filter import SubscriptionPeriodDemographicFilter
from linebot.v3.messaging.models.substitution_object import SubstitutionObject
from linebot.v3.messaging.models.template import Template
from linebot.v3.messaging.models.template_image_aspect_ratio import TemplateImageAspectRatio
from linebot.v3.messaging.models.template_image_size import TemplateImageSize
from linebot.v3.messaging.models.template_message import TemplateMessage
from linebot.v3.messaging.models.test_webhook_endpoint_request import TestWebhookEndpointRequest
from linebot.v3.messaging.models.test_webhook_endpoint_response import TestWebhookEndpointResponse
from linebot.v3.messaging.models.text_message import TextMessage
from linebot.v3.messaging.models.text_message_v2 import TextMessageV2
from linebot.v3.messaging.models.uri_action import URIAction
from linebot.v3.messaging.models.uri_imagemap_action import URIImagemapAction
from linebot.v3.messaging.models.update_rich_menu_alias_request import UpdateRichMenuAliasRequest
from linebot.v3.messaging.models.user_mention_target import UserMentionTarget
from linebot.v3.messaging.models.user_profile_response import UserProfileResponse
from linebot.v3.messaging.models.validate_message_request import ValidateMessageRequest
from linebot.v3.messaging.models.video_message import VideoMessage
