# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AudienceGroupJobFailedType(str, Enum):
    """
    Failed type
    """

    """
    allowed enum values
    """
    INTERNAL_ERROR = 'INTERNAL_ERROR'
    AUDIENCE_GROUP_AUDIENCE_INSUFFICIENT = 'AUDIENCE_GROUP_AUDIENCE_INSUFFICIENT'

    @classmethod
    def from_json(cls, json_str: str) -> AudienceGroupJobFailedType:
        """Create an instance of AudienceGroupJobFailedType from a JSON string"""
        return AudienceGroupJobFailedType(json.loads(json_str))


