# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AudienceGroupType(str, Enum):
    """
    Audience group type
    """

    """
    allowed enum values
    """
    UPLOAD = 'UPLOAD'
    CLICK = 'CLICK'
    IMP = 'IMP'
    CHAT_TAG = 'CHAT_TAG'
    FRIEND_PATH = 'FRIEND_PATH'
    RESERVATION = 'RESERVATION'
    APP_EVENT = 'APP_EVENT'
    VIDEO_VIEW = 'VIDEO_VIEW'
    WEBTRAFFIC = 'WEBTRAFFIC'
    IMAGE_CLICK = 'IMAGE_CLICK'
    RICHMENU_IMP = 'RICHMENU_IMP'
    RICHMENU_CLICK = 'RICHMENU_CLICK'

    @classmethod
    def from_json(cls, json_str: str) -> AudienceGroupType:
        """Create an instance of AudienceGroupType from a JSON string"""
        return AudienceGroupType(json.loads(json_str))


