# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class FlexMargin(str, Enum):
    """
    You can specify the minimum space before a child component with the `margin` property of the child component, in pixels or with a keyword. FlexMargin just provides only keywords. 
    """

    """
    allowed enum values
    """
    NONE = 'none'
    XS = 'xs'
    SM = 'sm'
    MD = 'md'
    LG = 'lg'
    XL = 'xl'
    XXL = 'xxl'

    @classmethod
    def from_json(cls, json_str: str) -> FlexMargin:
        """Create an instance of FlexMargin from a JSON string"""
        return FlexMargin(json.loads(json_str))


