# coding: utf-8

"""
    Webhook Type Definition

    Webhook event definition of the LINE Messaging API  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic.v1 import BaseModel, Field, conlist, constr, validator
from linebot.v3.webhooks.models.event import Event

class CallbackRequest(BaseModel):
    """
    The request body contains a JSON object with the user ID of a bot that should receive webhook events and an array of webhook event objects. 
    https://developers.line.biz/en/reference/messaging-api/#request-body
    """
    destination: constr(strict=True, max_length=33, min_length=33) = Field(..., description="User ID of a bot that should receive webhook events. The user ID value is a string that matches the regular expression, `U[0-9a-f]{32}`. ")
    events: conlist(Event) = Field(..., description="Array of webhook event objects. The LINE Platform may send an empty array that doesn't include a webhook event object to confirm communication. ")

    __properties = ["destination", "events"]

    @validator('destination')
    def destination_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^U[0-9a-f]{32}$", value):
            raise ValueError(r"must validate the regular expression /^U[0-9a-f]{32}$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CallbackRequest:
        """Create an instance of CallbackRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic.v1 by calling `to_dict()` of each item in events (list)
        _items = []
        if self.events:
            for _item in self.events:
                if _item:
                    _items.append(_item.to_dict())
            _dict['events'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CallbackRequest:
        """Create an instance of CallbackRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CallbackRequest.parse_obj(obj)

        _obj = CallbackRequest.parse_obj({
            "destination": obj.get("destination"),
            "events": [Event.from_dict(_item) for _item in obj.get("events")] if obj.get("events") is not None else None
        })
        return _obj

