# coding: utf-8

"""
    Webhook Type Definition

    Webhook event definition of the LINE Messaging API  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class EventMode(str, Enum):
    """
    Channel state.
    """

    """
    allowed enum values
    """
    ACTIVE = 'active'
    STANDBY = 'standby'

    @classmethod
    def from_json(cls, json_str: str) -> EventMode:
        """Create an instance of EventMode from a JSON string"""
        return EventMode(json.loads(json_str))


