# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AgeDemographic(str, Enum):
    """
    AgeDemographic
    """

    """
    allowed enum values
    """
    AGE_15 = 'age_15'
    AGE_20 = 'age_20'
    AGE_25 = 'age_25'
    AGE_30 = 'age_30'
    AGE_35 = 'age_35'
    AGE_40 = 'age_40'
    AGE_45 = 'age_45'
    AGE_50 = 'age_50'
    AGE_55 = 'age_55'
    AGE_60 = 'age_60'
    AGE_65 = 'age_65'
    AGE_70 = 'age_70'

    @classmethod
    def from_json(cls, json_str: str) -> AgeDemographic:
        """Create an instance of AgeDemographic from a JSON string"""
        return AgeDemographic(json.loads(json_str))


