# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic.v1 import Field, StrictStr, conlist
from linebot.v3.messaging.models.emoji import Emoji
from linebot.v3.messaging.models.message import Message
from linebot.v3.messaging.models.quick_reply import QuickReply
from linebot.v3.messaging.models.sender import Sender

class TextMessage(Message):
    """
    TextMessage
    https://developers.line.biz/en/reference/messaging-api/#text-message
    """
    text: StrictStr = Field(...)
    emojis: Optional[conlist(Emoji)] = None
    quote_token: Optional[StrictStr] = Field(None, alias="quoteToken", description="Quote token of the message you want to quote.")
    type: str = "text"

    __properties = ["type", "quickReply", "sender", "text", "emojis", "quoteToken"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TextMessage:
        """Create an instance of TextMessage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic.v1 by calling `to_dict()` of quick_reply
        if self.quick_reply:
            _dict['quickReply'] = self.quick_reply.to_dict()
        # override the default output from pydantic.v1 by calling `to_dict()` of sender
        if self.sender:
            _dict['sender'] = self.sender.to_dict()
        # override the default output from pydantic.v1 by calling `to_dict()` of each item in emojis (list)
        _items = []
        if self.emojis:
            for _item in self.emojis:
                if _item:
                    _items.append(_item.to_dict())
            _dict['emojis'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TextMessage:
        """Create an instance of TextMessage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TextMessage.parse_obj(obj)

        _obj = TextMessage.parse_obj({
            "type": obj.get("type"),
            "quick_reply": QuickReply.from_dict(obj.get("quickReply")) if obj.get("quickReply") is not None else None,
            "sender": Sender.from_dict(obj.get("sender")) if obj.get("sender") is not None else None,
            "text": obj.get("text"),
            "emojis": [Emoji.from_dict(_item) for _item in obj.get("emojis")] if obj.get("emojis") is not None else None,
            "quote_token": obj.get("quoteToken")
        })
        return _obj

