# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class RichMenuBatchProgressPhase(str, Enum):
    """
    The current status. One of:  `ongoing`: Rich menu batch control is in progress. `succeeded`: Rich menu batch control is complete. `failed`: Rich menu batch control failed.           This means that the rich menu for one or more users couldn't be controlled.           There may also be users whose operations have been successfully completed. 
    """

    """
    allowed enum values
    """
    ONGOING = 'ongoing'
    SUCCEEDED = 'succeeded'
    FAILED = 'failed'

    @classmethod
    def from_json(cls, json_str: str) -> RichMenuBatchProgressPhase:
        """Create an instance of RichMenuBatchProgressPhase from a JSON string"""
        return RichMenuBatchProgressPhase(json.loads(json_str))


