# -*- coding: utf-8 -*-

#  Licensed under the Apache License, Version 2.0 (the 'License'); you may
#  not use this file except in compliance with the License. You may obtain
#  a copy of the License at
#
#       https://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an 'AS IS' BASIS, WITHOUT
#  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#  License for the specific language governing permissions and limitations
#  under the License.

from __future__ import unicode_literals, absolute_import

import unittest

from linebot.models import LinearGradientBackground
from tests.models.serialize_test_case import SerializeTestCase


class TestBackground(SerializeTestCase):
    def test_background(self):
        arg = {
            "type": "linearGradient",
            "angle": "0deg",
            "start_color": "#ff0000",
            "end_color": "#0000ff"
        }
        self.assertEqual(
            self.serialize_as_dict(arg, type=self.LINEAR_GRADIENT),
            LinearGradientBackground(**arg).as_json_dict()
        )


if __name__ == '__main__':
    unittest.main()
