# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AudienceGroupStatus(str, Enum):
    """
    Status
    """

    """
    allowed enum values
    """
    IN_PROGRESS = 'IN_PROGRESS'
    READY = 'READY'
    FAILED = 'FAILED'
    EXPIRED = 'EXPIRED'
    INACTIVE = 'INACTIVE'
    ACTIVATING = 'ACTIVATING'

    @classmethod
    def from_json(cls, json_str: str) -> AudienceGroupStatus:
        """Create an instance of AudienceGroupStatus from a JSON string"""
        return AudienceGroupStatus(json.loads(json_str))


