# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic.v1 import BaseModel, Field, StrictStr, constr
from linebot.v3.messaging.models.action import Action

class QuickReplyItem(BaseModel):
    """
    QuickReplyItem
    https://developers.line.biz/en/reference/messaging-api/#items-object
    """
    image_url: Optional[constr(strict=True, max_length=2000)] = Field(None, alias="imageUrl", description="URL of the icon that is displayed at the beginning of the button")
    action: Optional[Action] = None
    type: Optional[StrictStr] = Field('action', description="`action`")

    __properties = ["imageUrl", "action", "type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> QuickReplyItem:
        """Create an instance of QuickReplyItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic.v1 by calling `to_dict()` of action
        if self.action:
            _dict['action'] = self.action.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> QuickReplyItem:
        """Create an instance of QuickReplyItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return QuickReplyItem.parse_obj(obj)

        _obj = QuickReplyItem.parse_obj({
            "image_url": obj.get("imageUrl"),
            "action": Action.from_dict(obj.get("action")) if obj.get("action") is not None else None,
            "type": obj.get("type") if obj.get("type") is not None else 'action'
        })
        return _obj

