# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class TemplateImageSize(str, Enum):
    """
    Size of the image.  This is only for the `imageSize` in ButtonsTemplate. Specify one of the following values:  `cover`: The image fills the entire image area. Parts of the image that do not fit in the area are not displayed. `contain`: The entire image is displayed in the image area. A background is displayed in the unused areas to the left and right of vertical images and in the areas above and below horizontal images. 
    """

    """
    allowed enum values
    """
    COVER = 'cover'
    CONTAIN = 'contain'

    @classmethod
    def from_json(cls, json_str: str) -> TemplateImageSize:
        """Create an instance of TemplateImageSize from a JSON string"""
        return TemplateImageSize(json.loads(json_str))


