# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class FlexBoxBorderWidth(str, Enum):
    """
    Width of box border. This is only for `borderWidth` in FlexBox. A value of none means that borders are not rendered; the other values are listed in order of increasing width. 
    """

    """
    allowed enum values
    """
    NONE = 'none'
    LIGHT = 'light'
    NORMAL = 'normal'
    MEDIUM = 'medium'
    SEMI_MINUS_BOLD = 'semi-bold'
    BOLD = 'bold'

    @classmethod
    def from_json(cls, json_str: str) -> FlexBoxBorderWidth:
        """Create an instance of FlexBoxBorderWidth from a JSON string"""
        return FlexBoxBorderWidth(json.loads(json_str))


