# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class FlexSpanSize(str, Enum):
    """
    Font size in the `size` property of the Flex span component. You can specify the size in pixels or with a keyword. FlexSpanSize just provides only keywords. 
    """

    """
    allowed enum values
    """
    XXS = 'xxs'
    XS = 'xs'
    SM = 'sm'
    MD = 'md'
    LG = 'lg'
    XL = 'xl'
    XXL = 'xxl'
    ENUM_3XL = '3xl'
    ENUM_4XL = '4xl'
    ENUM_5XL = '5xl'

    @classmethod
    def from_json(cls, json_str: str) -> FlexSpanSize:
        """Create an instance of FlexSpanSize from a JSON string"""
        return FlexSpanSize(json.loads(json_str))


